@@ -19,7 +19,7 @@ try:
 except Exception as e:
     print(f"importing torch failed with exception: {repr(e)}")
 
-from code_loader.contract.datasetclasses import DatasetSample, DatasetBaseHandler, InputHandler, \
+from code_loader.contract.datasetclasses import DatasetSample, DatasetBaseHandler, \
     GroundTruthHandler, PreprocessResponse, VisualizerHandler, VisualizerCallableReturnType, CustomLossHandler, \
     PredictionTypeHandler, MetadataHandler, CustomLayerHandler, MetricHandler
 from code_loader.contract.enums import DataStateEnum, TestingSectionEnum, DataStateType, DatasetMetadataType
@@ -28,7 +28,7 @@ from code_loader.contract.responsedataclasses import DatasetIntegParseResult, Da
     DatasetPreprocess, DatasetSetup, DatasetInputInstance, DatasetOutputInstance, DatasetMetadataInstance, \
     VisualizerInstance, PredictionTypeInstance, ModelSetup, CustomLayerInstance, MetricInstance, CustomLossInstance
 from code_loader.inner_leap_binder import global_leap_binder
-from code_loader.utils import get_root_exception_line_number, get_shape
+from code_loader.utils import get_root_exception_line_number
 
 
 class LeapLoader:
